/***************************************************************************                          
    file:           generalcfgdesign.cpp
    description:    general configuration design
    begin:          09/06/2024
    Copyright:      Giuseppe Della Bianca<giusdbg@gmail.com>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qvariant.h>
#include <qpushbutton.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qapplication.h>

#include <kaboutdata.h>
#include <klocalizedstring.h>

#include "general.h"
#include "generalcfgdesign.h"


/*
 *  Constructs a GeneralCfgDesign as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
GeneralCfgDesign::GeneralCfgDesign( QWidget* parent, const QString &name, Qt::WindowFlags fl )
    : QWidget( parent /*, name */, fl )
{
    QGridLayout *qglAppea, *qglPref, *qglUpdTime;
    QVBoxLayout *qvblPanelSize;
    
    if ( name.isEmpty() )
	setObjectName( "GeneralCfgDesign" );

    GeneralCfgDesignLayout = new QGridLayout( this ); 
    
    qtwMain = new QTabWidget( this );
    
    qwAppea = new QWidget( qtwMain );
    qglAppea = new QGridLayout( qwAppea );
    
    qwPref = new QWidget( qtwMain );
    qglPref = new QGridLayout( qwPref );
        
    ButtonGroup5 = new QGroupBox( qwAppea /*, "ButtonGroup5" */ );
    ButtonGroup5->setAlignment( Qt::Vertical );
//    ButtonGroup5->layout()->setSpacing( 6 );
//    ButtonGroup5->layout()->setMargin( 11 ); 
    ButtonGroup5Layout = new QGridLayout( ButtonGroup5 );
    ButtonGroup5Layout->setAlignment( Qt::AlignTop );
        
    qvblPanelSize = new QVBoxLayout (); 
    qlpanelSize = new QLabel( ButtonGroup5 );
    qvblPanelSize->addWidget( qlpanelSize );    
    qcbPanelSize = new QComboBox( ButtonGroup5 );
    qvblPanelSize->addWidget( qcbPanelSize );
    
    QStringList qslPanelSize = QStringList() << qsFL1( "1" ) << qsFL1( "2" ) << qsFL1( "3" ) << qsFL1( "4" ) << qsFL1( "5" )
    << qsFL1( "6" ) << qsFL1( "7" ) << qsFL1( "8" ) << qsFL1( "9" ) << qsFL1( "10" )
    << qsFL1( "11" ) << qsFL1( "12" ) << qsFL1( "13" ) << qsFL1( "14" ) << qsFL1( "15" );

    qcbPanelSize->insertItems( 0, qslPanelSize );
    qcbPanelSize->setGeometry( QRect(160, 50, 87, 32) );

    ButtonGroup5Layout->addLayout( qvblPanelSize, 0, 0, 1, 1 );    
//    ButtonGroup5Layout->addWidget ( qcbPanelSize, 0, 0 );    
    qglAppea->addWidget( ButtonGroup5, 0, 0 );

    qcbPanelSolid = new QCheckBox ( qwAppea );
    qcbPanelSolid->setChecked( true );
    
    ButtonGroup5Layout->addWidget( qcbPanelSolid, 1, 0 );
    
    qgbPanelOpacity = new QGroupBox( qwAppea );
    qgbPanelOpacity->setFlat( true );
    qhblPanelOpacity = new QHBoxLayout( qgbPanelOpacity );
    qhblPanelOpacity->setAlignment( Qt::AlignLeft );
    qhblPanelOpacity->setContentsMargins( 0, 0, 0, 0 );
    
    qlPanelOpacityLabel = new QLabel ( qwAppea );
    qlPanelOpacityLabel->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Preferred );
    qdsbPanelOpacityValue = new QDoubleSpinBox ( qwAppea );
    qdsbPanelOpacityValue->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Preferred );
    qdsbPanelOpacityValue->setDecimals ( 0 );
    qdsbPanelOpacityValue->setMinimum( 0.0 );
    qdsbPanelOpacityValue->setMaximum( 100.0 );
    qdsbPanelOpacityValue->setValue( 70 );
    qsiPanelOpacitySpacer = new QSpacerItem( 0, 0, QSizePolicy::Maximum, QSizePolicy::Preferred );
    
    qhblPanelOpacity->addWidget ( qlPanelOpacityLabel );
    qhblPanelOpacity->addWidget ( qdsbPanelOpacityValue );    
    qhblPanelOpacity->addItem( qsiPanelOpacitySpacer );
    ButtonGroup5Layout->addWidget( qgbPanelOpacity, 1, 1 );

    qcbWindowsSolid = new QCheckBox ( qwAppea );
    qcbWindowsSolid->setChecked( true );

    ButtonGroup5Layout->addWidget( qcbWindowsSolid, 2, 0 );
    
    qgbWindowsOpacity = new QGroupBox( qwAppea );
    qgbWindowsOpacity->setFlat( true );
    qhblWindowsOpacity = new QHBoxLayout( qgbWindowsOpacity );
    qhblWindowsOpacity->setContentsMargins( 0, 0, 0, 0 );
    
    qlWindowsOpacityLabel = new QLabel ( qwAppea );
    qlWindowsOpacityLabel->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Preferred );
    qdsbWindowsOpacityValue = new QDoubleSpinBox ( qwAppea );
    qdsbWindowsOpacityValue->setSizePolicy( QSizePolicy::Maximum, QSizePolicy::Preferred );
    qdsbWindowsOpacityValue->setDecimals ( 0 );
    qdsbWindowsOpacityValue->setMinimum( 0.0 );
    qdsbWindowsOpacityValue->setMaximum( 100.0 );
    qdsbWindowsOpacityValue->setValue( 70 );
    qsiWindowsOpacitySpacer = new QSpacerItem( 0, 0, QSizePolicy::Maximum, QSizePolicy::Preferred );
    
    qhblWindowsOpacity->addWidget ( qlWindowsOpacityLabel );
    qhblWindowsOpacity->addWidget ( qdsbWindowsOpacityValue );    
    qhblWindowsOpacity->addItem( qsiWindowsOpacitySpacer );
    ButtonGroup5Layout->addWidget( qgbWindowsOpacity, 2, 1 );
    
    boxGeneralPalette = new QGroupBox( qwAppea );
    boxGeneralPalette->setMinimumSize( QSize( 0, 90 ) );
    qglAppea->addWidget( boxGeneralPalette, 1, 0 );
    
    GroupBox2 = new QGroupBox( qwAppea );
    GroupBox2->setAlignment( Qt::Vertical );
//    GroupBox2->layout()->setSpacing( 6 );
//    GroupBox2->layout()->setMargin( 11 );
    GroupBox2Layout = new QVBoxLayout( GroupBox2 );
    GroupBox2Layout->setAlignment( Qt::AlignTop );

    CheckBoxAutoStart = new QCheckBox( GroupBox2 /*, "CheckBoxAutoStart" */ );
    GroupBox2Layout->addWidget( CheckBoxAutoStart );

    qglAppea->addWidget( GroupBox2, 2, 0 );
    Spacer28 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );        
    qglAppea->addItem( Spacer28, 3, 0 );
    
    qtwMain->addTab( qwAppea, QString() );
        
    qgbUpdTime = new QGroupBox( qwPref );
    qgbUpdTime->setAlignment( Qt::Vertical );
    
    qglUpdTime = new QGridLayout( qgbUpdTime );
    qglUpdTime->setAlignment( Qt::AlignTop );

    qdsbUpdTime = new QDoubleSpinBox( qgbUpdTime );
    qdsbUpdTime->setSuffix ( qsFL1( "s" ) );
    qdsbUpdTime->setDecimals( 1 );
    qdsbUpdTime->setSingleStep( 0.5 );
    qdsbUpdTime->setMinimum( 0.5 );
    qdsbUpdTime->setValue( 5.0 );

    qglUpdTime->addWidget( qdsbUpdTime, 0, 0 );

    qsUpdTime = new QSlider( qgbUpdTime );
    qsUpdTime->setPageStep( 5 );
    qsUpdTime->setSingleStep( 5 );
    qsUpdTime->setMinimum( 5 );
    qsUpdTime->setMaximum( 600 );
    qsUpdTime->setValue( 50 );
    qsUpdTime->setOrientation( Qt::Horizontal );

    qglUpdTime->addWidget( qsUpdTime, 0, 1 );

    qglPref->addWidget( qgbUpdTime, 1, 0 );
    qtwMain->addTab( qwPref, QString() );

    GeneralCfgDesignLayout->addWidget( qtwMain, 0, 0 );
    
    languageChange();
//    resize( QSize(343, 239).expandedTo(minimumSizeHint()) );
//   clearWState( WState_Polished );
    
    connect( qcbPanelSolid, &QAbstractButton::toggled, this, &GeneralCfgDesign::slotPanelSolidToggled );
    connect( qcbWindowsSolid, &QAbstractButton::toggled, this, &GeneralCfgDesign::slotWindowsSolidToggled );    
    connect( qsUpdTime, SIGNAL( valueChanged( int) ), this, SLOT( slotUpdateTimeSliderValue( int ) ) );
    connect( qdsbUpdTime, SIGNAL( valueChanged( double ) ), this, SLOT( slotUpdateTimeSpinValue( double ) ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
GeneralCfgDesign::~GeneralCfgDesign()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void GeneralCfgDesign::languageChange()
{
    const KAboutData kadAboutData = KAboutData::applicationData();
    
    setWindowTitle( tr2i18n( "GeneralCfg" ) );
        
    ButtonGroup5->setTitle( tr2i18n( "Panels appearance" ) );

    qlpanelSize->setText ( qsFL1( "Panels size" ) );
    qcbPanelSize->setItemText( 0, tr2i18n ( "160 x 160" ) );
    qcbPanelSize->setItemText( 1, tr2i18n ( "152 x 152" ) );
    qcbPanelSize->setItemText( 2, tr2i18n ( "144 x 144" ) );
    qcbPanelSize->setItemText( 3, tr2i18n ( "136 x 136" ) );
    qcbPanelSize->setItemText( 4, tr2i18n ( "128 x 128" ) );
    qcbPanelSize->setItemText( 5, tr2i18n ( "120 x 120" ) );
    qcbPanelSize->setItemText( 6, tr2i18n ( "112 x 112" ) );
    qcbPanelSize->setItemText( 7, tr2i18n ( "104 x 104" ) );
    qcbPanelSize->setItemText( 8, tr2i18n ( "96 x 96" ) );
    qcbPanelSize->setItemText( 9, tr2i18n ( "88 x 88" ) );  
    qcbPanelSize->setItemText( 10, tr2i18n ( "80 x 80" ) );
    qcbPanelSize->setItemText( 11, tr2i18n ( "72 x 72" ) );
    qcbPanelSize->setItemText( 12, tr2i18n ( "64 x 64" ) );
    qcbPanelSize->setItemText( 13, tr2i18n ( "56 x 56" ) );
    qcbPanelSize->setItemText( 14, tr2i18n ( "48 x 48" ) );
    qcbPanelSize->setCurrentText ( tr2i18n ( "64 x 64" ) );

    qcbPanelSolid->setText( qsFL1( "Solid" ) );
    qlPanelOpacityLabel->setText( qsFL1( "Opacity" ) );
    qdsbPanelOpacityValue->setSuffix( qsFL1( "%" ) );

    qcbWindowsSolid->setText( qsFL1( "Windows Solid" ) );
    qlWindowsOpacityLabel->setText( qsFL1( "Windows Opacity" ) );
    qdsbWindowsOpacityValue->setSuffix( qsFL1( "%" ) );


    boxGeneralPalette->setTitle( tr2i18n( "Colors" ) );
    GroupBox2->setTitle( tr2i18n( "Startup" ) );
    CheckBoxAutoStart->setText( tr2i18n( ( qsFL1( "Autostart " ) + kadAboutData.displayName() + qsFL1( " on KDE startup" ) ).toLatin1().data() ) );
    
    qtwMain->setTabText( qtwMain->indexOf( qwAppea ), tr2i18n( "Appearance" ) );
    qtwMain->setTabText( qtwMain->indexOf( qwPref ), tr2i18n( "Preferences" ) );
    
    qgbUpdTime->setTitle( tr2i18n( "Update interval" ) );

}

void GeneralCfgDesign::slotPanelSolidToggled( bool checked )
{
    if ( checked )
        qdsbPanelOpacityValue->setValue( 100.0 );
    else
        qdsbPanelOpacityValue->setValue( 70.0 );
}

void GeneralCfgDesign::slotWindowsSolidToggled( bool checked )
{
    if ( checked )
        qdsbWindowsOpacityValue->setValue( 100.0 );
    else
        qdsbWindowsOpacityValue->setValue( 70.0 );
}

void GeneralCfgDesign::slotUpdateTimeSliderValue( int value )
{
    qdsbUpdTime->setValue( ( value / 10.0 ) );        
}

void GeneralCfgDesign::slotUpdateTimeSpinValue( double value )
{
    qsUpdTime->setValue( ( value * 10.0 ) );        
}

//#include "generalcfgdesign.moc"
