/***************************************************************************
                          sensorslist.h  -  description
                             -------------------
    begin                : 09/06/2024
    Copyright	Giuseppe Della Bianca<giusdbg@gmail.com>

    original author	 : Miguel Novas
    email                : michaell@teleline.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SENSORSLIST_H
#define SENSORSLIST_H

#include <qobject.h>
// #include <qobjcoll.h>
#include <qstringlist.h>

#include "sensor.h"
#include "ksensorssetting.h"


/**
  *@original author Miguel Novas
  */

class SensorsList : public QObject, public ksensorsSetting
{
Q_OBJECT

  friend class Sensor;

public:

	SensorsList(QObject *parent = nullptr, const QString &name = QString() );
	~SensorsList();

  void setMonitorized (bool enable);
  bool getMonitorized();

  const QObjectList *getSensors()           { return &children(); };
  Sensor *getSensor(int index)              { return !children().isEmpty() ? (Sensor *)children().at(index) : nullptr; }
  Sensor *getSensor( const QString &name )  { return findChild<Sensor *>(name); }    
  int count() 				    { return !children().isEmpty() ? children().count() : 0; }

  void setTempScale(Sensor::TempScale scale);
  Sensor::TempScale getTempScale()       { return tempScale; }

    void setClass( Sensor::SensorClass newClass);    
    Sensor::SensorClass getClass();

    void setShortName( const QString &name );
    QString getShortName();
    void setLongName( const QString &name );
    QString getLongName();
    void setSubName( const QString &name );
    QString getSubName();
    void setDescription( const QString &desc );
    const QString &getDescription();

    void setObjectName( const QString &name );

    void setConfUpdateInterval( double seconds );
    double getConfUpdateInterval ( bool enabSec = true );
    void setSensorUpdateInterval( double seconds );
    double getSensorUpdateInterval( bool enabSec = true );

    void globalTimerUpdate ( int updateIntervalIn, int updateIntervalTimerIn );
    void setWithGlobalTimerUpdate ( bool withGlobalTimerUpdateIn );

public Q_SLOTS:

  virtual void updateSensors( bool enabUpdate ) = 0;
  virtual void readConfig();
  virtual void writeConfig();

Q_SIGNALS:

  void valueChanged(Sensor *);

protected Q_SLOTS:

  void slotValueChanged();

protected:
  
  void childEvent ( QChildEvent *e ) override;

private:

    Sensor::TempScale tempScale;
    Sensor::SensorClass sensorClass;

    QString shortName;
    QString longName;
    QString subName;

    QString description;

  bool monitorized;  
//  KConfig *ksConfig;

    int idTimer;

    int confUpdateInterval;
    int sensorUpdateInterval;
    int timerUpdateInterval;
    bool withGlobalTimerUpdate;

    void timerEvent( QTimerEvent * ) override;
};

#endif
